@@ -92,14 +92,14 @@ n.write_to_file(filename="output.nex", interleave=True, charblock=True)
 
 """
 __author__ = 'Simon Greenhill <simon@simon.net.nz>'
-__version__ = "1.7"
+__version__ = "1.32"
 PACKAGE_NAME = "python-nexus"
 PACKAGE_VERSION = __version__
 VERSION = __version__
 PACKAGE_AUTHOR = "Simon J. Greenhill"
-PACKAGE_COPYRIGHT = "Copyright 2009-2019 Simon J. Greenhill"
+PACKAGE_COPYRIGHT = "Copyright 2009-2015 Simon J. Greenhill"
 PACKAGE_LICENSE = """
-Copyright (c) 2009-2019, Simon J. Greenhill
+Copyright (c) 2009-2015, Simon J. Greenhill
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification
@@ -128,11 +128,8 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-from nexus.reader import NexusReader
-from nexus.writer import NexusWriter
-from nexus import handlers
-from nexus.exceptions import NexusFormatException
-from nexus import bin
-from nexus import tools
+from .reader import NexusFormatException, NexusReader
+from .writer import NexusWriter
+from . import tools
 
-__all__ = ["NexusReader", "NexusWriter", "NexusFormatException", "handlers", "tools", "bin"]
+__all__ = ["NexusReader", "NexusWriter", "NexusFormatException", "tools"]
