@@ -9,18 +9,17 @@ __doc__ = """nexus_anonymise - python-nexus tools v%(version)s
 Anonymises the taxa in a nexus
 """ % {'version': VERSION, }
 
-def anonymise(nexus_obj, salt=None):
+def anonymise(nexus_obj):
     """Anonymises a nexus object"""
-    _done_data = False  # flag so we don't double randomise
     for block in nexus_obj.blocks:
         if block == 'taxa':
             for idx, t in enumerate(nexus_obj.blocks[block].taxa):
-                nexus_obj.blocks[block].taxa[idx] = hash(salt, t)
+                nexus_obj.blocks[block].taxa[idx] = hash(nexus_obj.filename, t)
         elif block == 'trees':
             if nexus_obj.blocks[block].was_translated:
                 for idx in nexus_obj.blocks[block].translators:
                     h = hash(
-                        salt,
+                        nexus_obj.filename,
                         nexus_obj.blocks[block].translators[idx]
                     )
                     nexus_obj.blocks[block].translators[idx] = h
@@ -28,26 +27,22 @@ def anonymise(nexus_obj, salt=None):
                 raise NotImplementedError(
                     "Unable to anonymise untranslated trees"
                 )
-        elif block in ('data', 'characters'):
-            if _done_data:
-                continue
+        elif block == 'data':
             newmatrix = {}
             for t in nexus_obj.blocks[block].matrix:
-                newmatrix[hash(salt, t)] = nexus_obj.blocks[block].matrix[t]
+                newmatrix[hash(nexus_obj.filename, t)] = \
+                    nexus_obj.blocks[block].matrix[t]
             nexus_obj.blocks[block].matrix = newmatrix
-            
-            if block == 'characters':
-                nexus_obj.blocks['data'].matrix = newmatrix
-            _done_data = True
+
         else:
-            raise NotImplementedError("Unable to anonymise `%s` blocks" % block)
+            raise NotImplementedError("Unable to anonymise %s blocks" % block)
     return nexus_obj
 
 
-def hash(salt, value):
-    return hashlib.md5(("%s-%s" % (salt, value)).encode('ascii')).hexdigest()
+def hash(salt, taxon):
+    return hashlib.md5(("%s-%s" % (salt, taxon)).encode('ascii')).hexdigest()
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == '__main__':
     from optparse import OptionParser
     parser = OptionParser(usage="usage: %prog fudge.nex output.nex")
     options, args = parser.parse_args()
