@@ -1,5 +1,5 @@
 from nexus.writer import NexusWriter
-from nexus.tools import check_for_valid_NexusReader
+from nexus.tools.check_for_valid_NexusReader import check_for_valid_NexusReader
 
 # set isstr in a python 2 vs python 3 safe way
 try:
